%w(version connections).each do |f|
  require "beanpool/#{f}"
end

class Beanpool
  attr_reader :connections

  def initialize(ip_array, debug = false)
    raise 'Beanpool must be initialized with an array of IP addresses' unless ip_array.is_a?(Array) && !ip_array.empty?
    @connections = Beanpool::Connections.new(ip_array, debug)
  end

  def put(body, options)
    @connections.put_job_to_tube(body, options)
  end

  def get(timeout = nil, tube_name = 'default')
    @connections.get_job_from_tube(timeout, tube_name)
  end

  def close
    @connections.close
  end

  def stats(tube_name)
    @connections.all_stats(tube_name)
  rescue => ex
    BlitlineLogger.log(ex)
    return {}
  end

  def use_tube(tube_name)
    @connections.use_tube(tube_name)
  end

  def get_stat_by_tube(tube_name, stat_name)
    @connections.stats(tube_name, stat_name)
  end

  def get_ready_by_tube(name)
    @connections.stats(name, :current_jobs_ready)
  end

  def size
    @connections.stats('default', :current_jobs_ready)
  end


end
